pty_process::blocking

Struct Command

pub struct Command { /* private fields */ }
Wrapper around std::process::Command

Implementations

Source

impl Command

pub fn new<S: AsRef<OsStr>>(program: S) -> Self

pub fn arg<S: AsRef<OsStr>>(&mut self, arg: S) -> &mut Self

pub fn args<I, S>(&mut self, args: I) -> &mut Self
where I: IntoIterator<Item = S>, S: AsRef<OsStr>,

pub fn env<K, V>(&mut self, key: K, val: V) -> &mut Self
where K: AsRef<OsStr>, V: AsRef<OsStr>,

pub fn envs<I, K, V>(&mut self, vars: I) -> &mut Self
where I: IntoIterator<Item = (K, V)>, K: AsRef<OsStr>, V: AsRef<OsStr>,

pub fn env_remove<K: AsRef<OsStr>>(&mut self, key: K) -> &mut Self

pub fn env_clear(&mut self) -> &mut Self

pub fn current_dir<P: AsRef<Path>>(&mut self, dir: P) -> &mut Self

pub fn stdin<T: Into<Stdio>>(&mut self, cfg: T) -> &mut Self

pub fn stdout<T: Into<Stdio>>(&mut self, cfg: T) -> &mut Self

pub fn stderr<T: Into<Stdio>>(&mut self, cfg: T) -> &mut Self

pub fn spawn(&mut self, pts: &Pts) -> Result<Child>

Executes the command as a child process via std::process::Command::spawn on the given pty. The pty will be attached to all of stdin, stdout, and stderr of the child, unless those file descriptors were previously overridden through calls to stdin, stdout, or stderr. The newly created child process will also be made the session leader of a new session, and will have the given pty set as its controlling terminal.

Errors

Returns an error if we fail to allocate new file descriptors for attaching the pty to the child process, or if we fail to spawn the child process (see the documentation for std::process::Command::spawn), or if we fail to make the child a session leader or set its controlling terminal.

pub fn uid(&mut self, id: u32) -> &mut Self

pub fn gid(&mut self, id: u32) -> &mut Self

pub unsafe fn pre_exec<F>(&mut self, f: F) -> &mut Self
where F: FnMut() -> Result<()> + Send + Sync + 'static,

pub fn arg0<S>(&mut self, arg: S) -> &mut Self
where S: AsRef<OsStr>,